# SWC_packageinstaller

##### Easily installs packages from the Software City Projects Repository to your machine.

### Commands
`swcpm`
* `info <package>` Gives into about a package
* `install <package>` Installs a package
* `run <package>` Runs executable packages
* `remove <package>` Removes a package
* `wget <url>` Uses built-in installer like linux wget
* `debug` Lists all command modules

Standard installation directory:
`/home/<user>/SWC/Packages` or `C:\Users\<user>\SWC\Packages`